@@ -1,6 +1,6 @@
 package Map::Tube::Barcelona;
 
-$Map::Tube::Barcelona::VERSION = '0.07';
+$Map::Tube::Barcelona::VERSION = '0.08';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::Barcelona - Interface to the Barcelona Metro Map.
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
@@ -26,10 +26,41 @@ with 'Map::Tube';
 =head1 DESCRIPTION
 
 It currently provides functionality to find the shortest  route between  the  two
-given nodes. It covers lines L3, L4 & L11 only for now.I will be adding remaining
-routes very soon.
+given stations. It covers the following Barcelona Metro Lines just yet:
 
-For more information about Barcelona Metro Map, click L<here|http://www.barcelona-tourist-guide.com/en/maps/barcelona-metro-map-printable.html>.
+=over 2
+
+=item * L<L3 Line|Map::Tube::Barcelona::Line::L3>
+
+=item * L4 Line
+
+=item * L11 Line
+
+=back
+
+=head1 TODO (Metro Lines)
+
+=over 2
+
+=item * L1 Line
+
+=item * L2 Line
+
+=item * L4 Line
+
+=item * L5 Line
+
+=item * L6 Line
+
+=item * L7 Line
+
+=item * L8 Line
+
+=item * L9 Line
+
+=item * L10 Line
+
+=back
 
 =head1 CONSTRUCTOR
 
